@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from datetime import datetime
 from orionis.console.entities.scheduler_event_data import SchedulerEventData
 
 @dataclass(kw_only=True)
@@ -9,17 +10,24 @@ class SchedulerPaused(SchedulerEventData):
     This data class extends `SchedulerEventData` and encapsulates information
     related to the scheduler pause event, such as the time at which the pause occurred.
 
+    Parameters
+    ----------
+    time : str or datetime, optional
+        The time when the scheduler was paused. Can be a string or a `datetime` object.
+        Defaults to None.
+    (Other parameters are inherited from SchedulerEventData.)
+
     Attributes
     ----------
-    time : str
-        The time when the scheduler was paused, formatted as a string.
+    time : str or datetime
+        The time when the scheduler was paused.
     (Other attributes are inherited from SchedulerEventData.)
 
     Returns
     -------
     SchedulerPaused
-        An instance of SchedulerPaused containing information about the pause event.
+        An instance of `SchedulerPaused` containing information about the pause event.
     """
 
-    # The time when the scheduler was paused
-    time: str
\ No newline at end of file
+    # The time when the scheduler was paused; can be a string or datetime object
+    time: str | datetime = None
